(ns design
  (:require [portfolio.ui :as ui]
            [portfolio.dumdom :as d]
            [portfolio.dom :as r]))


(defn left-bar []
  [:div.m-4.p-4.text-2xl
   [:h1.mb-8 [:i.fa-solid.fa-gear.ml-4] "Oliver Marks - Software Engineer"]
   [:p.m-8 "Example projects"]])

(defn right-bar []
  [:div 
   [:div.skew-x-12.bg-slate-400.m-4
    [:ul.flex [:li.m-2 "item 1"] [:li.m-2 "item 2"] [:li.m-2 "item 3"]]]])

(defn page-header []
  [:header.flex.mb-12
   (left-bar)
   [:div.grow]
   (right-bar)]
  )


(defn tile [{:keys [title image description]}]
  [:div.rounded-lg.mb-8
   [:h3 title]
   [:img {:src "https://img.theplantscape.com/api/image/missing.jpg?p=medium"}]
   [:p description]])

(defn skills-list [title skills]
  [:div.mb-8
   [:h3.m-4.text-2xl title]
   (into [:ul]
         (mapv (fn skill-item [{:keys [direction icon skill]}]
                 (if (= direction "right") 
                   [:li.m-2.text-xl [:span [:i.mr-4 {:class (str "devicon-" icon "-plain")}] skill]]
                   [:li.m-2.text-xl [:span skill [:i.ml-4 {:class (str "devicon-" icon "-plain")}]]]
                   )
                 ) skills))])

(defn dual-column-circle []
  [:section.w-full.flex
   [:div.align-middle.relative.text-right {:class "w-1/2" :style {:width "50%"}}
    [:div.ml-8 {:style {:float "right" :right "0px" :width "200px" :height "400px" :background-color "#666666"
                   ;;:border-radius "100px"
                   :border-radius "200px 0px 0px 200px"
                            ;;:border-top-right-radius "50%" :border-bottom-right-radius "50%"

                            :shape-outside "circle(200px at 200px 200px)"}}]
    (skills-list "Operations"
                 [{:icon "googlecloud" :skill "Google Cloud"}
                  {:icon "digitalocean" :skill "Digitalocean"}
                  {:icon "docker" :skill "Docker"}
                  {:icon "kubernetes" :skill "Kubernetes"}])
    (tile {:title "GASP Air quality sensor"
           :image "https://img.theplantscape.com/api/image/missing.jpg?p=medium"
           :description "Single page site, which display's data relayed via mqtt from a physical device."})
    (tile {:title "Image scaling & resizing"
           :image "https://img.theplantscape.com/api/image/missing.jpg?p=medium"
           :description "API to upload image's and handle scaling to different sizes"})

    ]
   [:div.align-middle.relative.text-left {:class "w-1/2" :style {:width "50%"}}
    [:div.mr-8 {:style {:float "left" :width "200px" :height "400px" :background-color "#666666"
                   ;;:border-radius "100px"
                   :border-radius "0px 200px 200px 0px"


                            ;;:border-top-right-radius "50%" :border-bottom-right-radius "50%"
                   :shape-outside "circle(220px at 0px 200px)"}}]
    (skills-list
     "Development"
     [{:direction "right" :icon "clojure" :skill "Clojure"}
      {:direction "right" :icon "javascript" :skill "Javascript"}
      {:direction "right" :icon "python" :skill "Python"}
      {:direction "right" :icon "c" :skill "C / Arduino"}])
    (tile {:title "GASP Air quality sensor"
           :image "https://img.theplantscape.com/api/image/missing.jpg?p=medium"
           :description "Single page site, which display's data relayed via mqtt from a physical device."})
    (tile {:title "GASP Air quality sensor"
           :image "https://img.theplantscape.com/api/image/missing.jpg?p=medium"
           :description "Single page site, which display's data relayed via mqtt from a physical device."})]])

(d/defscene circle 
  dual-column-circle
  )

(defn footer-blocks [blocks]
  (into [:div.grid.grid-cols-2.gap-8.sm:gap-6.sm:grid-cols-3]
        (mapv (fn footer-block [{:keys [title children]}]
                [:div [:h2.mb-6.text-sm.font-semibold.text-gray-900.uppercase.dark:text-white title]
                 (into      [:ul.text-gray-500.dark:text-gray-400.font-medium]
                            (mapv (fn footer-link [{:keys [title link]}]
                                    [:li.mb-4 [:a.hover:underline {:href link} title]]) children))])
              blocks)))

(defn page-footer []
  [:section.flex.flex-row
   [:img.rounded-full {:src "https://img.theplantscape.com/api/image/missing.jpg?p=medium"}]
   (footer-blocks [{:title "header" :children [{:title "Reference"
                                            :children [{:link "" :title "Find Plant"}
                                                       {:link "" :title "Polycultures"}]}
                                           {:title "Design"
                                            :children [{:link "" :title "Polyculture"}
                                                       {:link "" :title "Garden"}]}
                                           {:title "Social / Contact Me"
                                            :children [{:link "https://matrix.to/#/#theplantscape.com:matrix.org" :title "Chat"}
                                                       {:link "https://fo.llow.social/u/olymk2@mastodon.social" :title "Masterdon"}]}] }])
   [:div [:h2 "header"
          [:ul
           [:li "linie 1"]]]]]


;; <div><h2 class="mb-6 text-sm font-semibold text-gray-900 uppercase dark:text-white">Design</h2><ul class="text-gray-500 dark:text-gray-400 font-medium"><li class="mb-4"><a href="/polycultures" class="hover:underline">Polyculture</a></li><li class="mb-4"><a href="/diagrams" class="hover:underline">Garden</a></li></ul></div>
  )

(d/defscene header
  page-header)

(d/defscene footer
  page-footer)


(d/defscene page
  [:div.bg-slate-200
   [:div {:class "m-4/5"}
    (page-header)
    (dual-column-circle)
    (page-footer)]])


(defn launch []
  (ui/start!
   {:config {:css-paths ["/css/styles.css"
                         "https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.1.1/css/all.min.css"
                         "https://cdn.jsdelivr.net/gh/devicons/devicon@v2.15.1/devicon.min.css"]}}))

